Interface: ScriptableTooltipContext | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ScriptableTooltipContext<TType>

## # Type parameters

Name | Type
--- | ---
`TType` | extends `ChartType`

## # Properties

### # chart

• chart: `Chart`<`TType`, `DistributiveArray`<`ChartTypeRegistry`[`TType`][`"defaultDataPoint"`]>, `unknown`>

#### # Defined in

index.esm.d.ts:2605
(opens new window)

### # tooltip

• tooltip: `TooltipModel`<`TType`>

#### # Defined in

index.esm.d.ts:2606
(opens new window)

### # tooltipItems

• tooltipItems: `TooltipItem`<`TType`>[]

#### # Defined in

index.esm.d.ts:2607
(opens new window)